.. PyYtLounge documentation master file, created by
   sphinx-quickstart on Fri Feb 23 13:45:36 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyYtLounge's documentation!
======================================

**PyYtLounge** is a Python library to interact with the unofficial and undocumented YouTube Lounge API.
This allows interaction with YouTube apps across device types such as a smart TV or gaming consoles.
The API has functions for controlling the device and to receive status updates from the device.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
